==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/BaSlsq.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;
import cn.gtmap.realestate.supervise.core.reflect.qxdm;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 登记受理申请信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_slsq"
)
public class BaSlsq implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @ywh
    private String ywh;

    @XmlAttribute
    private String sqlx;

    @XmlAttribute
    private String djdl;

    @XmlAttribute
    @Nullable
    private String djxl;

    @XmlAttribute
    private int sqzsbs;

    @XmlAttribute
    private int sqfbcz;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    private String slry;

    @XmlAttribute
    private Date slsj;

    @XmlAttribute
    @Nullable
    private String zl;

    @XmlAttribute
    @Nullable
    private String tzrxm;

    @XmlAttribute
    @Nullable
    private String tzfs;

    @XmlAttribute
    @Nullable
    private String tzrdh;

    @XmlAttribute
    @Nullable
    private String tzryddh;

    @XmlAttribute
    @Nullable
    private String tzrdzyj;

    @XmlAttribute
    @Nullable
    private String sfwtaj;

    @XmlAttribute
    @Nullable
    private Date jssj;

    @XmlAttribute
    @Nullable
    private String ajzt;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    private String bdcdyh;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getYwh() {
        return ywh;
    }

    public String getDjdl() {
        return djdl;
    }

    public String getDjxl() {
        return djxl;
    }

    public int getSqzsbs() {
        return sqzsbs;
    }

    public int getSqfbcz() {
        return sqfbcz;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getSlry() {
        return slry;
    }

    public Date getSlsj() {
        return slsj;
    }

    public String getZl() {
        return zl;
    }

    public String getTzrxm() {
        return tzrxm;
    }

    public String getTzfs() {
        return tzfs;
    }

    public String getTzrdh() {
        return tzrdh;
    }

    public String getTzryddh() {
        return tzryddh;
    }

    public String getTzrdzyj() {
        return tzrdzyj;
    }

    public String getSfwtaj() {
        return sfwtaj;
    }

    public Date getJssj() {
        return jssj;
    }

    public String getAjzt() {
        return ajzt;
    }

    public String getBz() {
        return bz;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setDjdl(String djdl) {
        this.djdl = djdl;
    }

    public void setDjxl(String djxl) {
        this.djxl = djxl;
    }

    public void setSqzsbs(int sqzsbs) {
        this.sqzsbs = sqzsbs;
    }

    public void setSqfbcz(int sqfbcz) {
        this.sqfbcz = sqfbcz;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setSlry(String slry) {
        this.slry = slry;
    }

    public void setSlsj(Date slsj) {
        this.slsj = slsj;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public void setTzrxm(String tzrxm) {
        this.tzrxm = tzrxm;
    }

    public void setTzfs(String tzfs) {
        this.tzfs = tzfs;
    }

    public void setTzrdh(String tzrdh) {
        this.tzrdh = tzrdh;
    }

    public void setTzryddh(String tzryddh) {
        this.tzryddh = tzryddh;
    }

    public void setTzrdzyj(String tzrdzyj) {
        this.tzrdzyj = tzrdzyj;
    }

    public void setSfwtaj(String sfwtaj) {
        this.sfwtaj = sfwtaj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public void setAjzt(String ajzt) {
        this.ajzt = ajzt;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }
}

==> realestate-supervise-common-1.0.0-20210224.062454-42-sources.jar: cn/gtmap/realestate/supervise/entity/BaSlsq.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;
import cn.gtmap.realestate.supervise.core.reflect.qxdm;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 登记受理申请信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_slsq"
)
public class BaSlsq implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @ywh
    private String ywh;

    @XmlAttribute
    private String sqlx;

    @XmlAttribute
    private String djdl;

    @XmlAttribute
    @Nullable
    private String djxl;

    @XmlAttribute
    private int sqzsbs;

    @XmlAttribute
    private int sqfbcz;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    private String slry;

    @XmlAttribute
    private Date slsj;

    @XmlAttribute
    @Nullable
    private String zl;

    @XmlAttribute
    @Nullable
    private String tzrxm;

    @XmlAttribute
    @Nullable
    private String tzfs;

    @XmlAttribute
    @Nullable
    private String tzrdh;

    @XmlAttribute
    @Nullable
    private String tzryddh;

    @XmlAttribute
    @Nullable
    private String tzrdzyj;

    @XmlAttribute
    @Nullable
    private String sfwtaj;

    @XmlAttribute
    @Nullable
    private Date jssj;

    @XmlAttribute
    @Nullable
    private String ajzt;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    private String bdcdyh;

    @Nullable
    private Date sjgxsj;

    @Nullable
    private String sjly;

    @bwmc
    private String bwmc;




    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getYwh() {
        return ywh;
    }

    public String getDjdl() {
        return djdl;
    }

    public String getDjxl() {
        return djxl;
    }

    public int getSqzsbs() {
        return sqzsbs;
    }

    public int getSqfbcz() {
        return sqfbcz;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getSlry() {
        return slry;
    }

    public Date getSlsj() {
        return slsj;
    }

    public String getZl() {
        return zl;
    }

    public String getTzrxm() {
        return tzrxm;
    }

    public String getTzfs() {
        return tzfs;
    }

    public String getTzrdh() {
        return tzrdh;
    }

    public String getTzryddh() {
        return tzryddh;
    }

    public String getTzrdzyj() {
        return tzrdzyj;
    }

    public String getSfwtaj() {
        return sfwtaj;
    }

    public Date getJssj() {
        return jssj;
    }

    public String getAjzt() {
        return ajzt;
    }

    public String getBz() {
        return bz;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setDjdl(String djdl) {
        this.djdl = djdl;
    }

    public void setDjxl(String djxl) {
        this.djxl = djxl;
    }

    public void setSqzsbs(int sqzsbs) {
        this.sqzsbs = sqzsbs;
    }

    public void setSqfbcz(int sqfbcz) {
        this.sqfbcz = sqfbcz;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setSlry(String slry) {
        this.slry = slry;
    }

    public void setSlsj(Date slsj) {
        this.slsj = slsj;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public void setTzrxm(String tzrxm) {
        this.tzrxm = tzrxm;
    }

    public void setTzfs(String tzfs) {
        this.tzfs = tzfs;
    }

    public void setTzrdh(String tzrdh) {
        this.tzrdh = tzrdh;
    }

    public void setTzryddh(String tzryddh) {
        this.tzryddh = tzryddh;
    }

    public void setTzrdzyj(String tzrdzyj) {
        this.tzrdzyj = tzrdzyj;
    }

    public void setSfwtaj(String sfwtaj) {
        this.sfwtaj = sfwtaj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public void setAjzt(String ajzt) {
        this.ajzt = ajzt;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

}
